@@ -3,7 +3,7 @@ import gtk, gobject, glipper, gconf
 class Clipboards(gobject.GObject):
 
 	__gsignals__ = {
-		"new-item" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_STRING]),
+		"new-item" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_STRING, gobject.TYPE_BOOLEAN]),
 	}
 
 	def __init__(self):
@@ -12,20 +12,23 @@ class Clipboards(gobject.GObject):
 		                                   self.emit_new_item,
 		                                   glipper.GCONF_USE_DEFAULT_CLIPBOARD)
 		self.primary_clipboard = Clipboard(gtk.clipboard_get("PRIMARY"),
-		                                   self.emit_new_item,
+		                                   self.emit_new_item_selection,
 		                                   glipper.GCONF_USE_PRIMARY_CLIPBOARD)
 		
 	def set_text(self, text):
 		self.default_clipboard.set_text(text)
 		self.primary_clipboard.set_text(text)
 
-		self.emit('new-item', text)
+		self.emit('new-item', text, False)
 		
 	def get_default_clipboard_text(self):
 		return self.default_clipboard.get_text()
 	
 	def emit_new_item(self, item):
-		self.emit('new-item', item)
+		self.emit('new-item', item, False)
+	
+	def emit_new_item_selection(self, item):
+		self.emit('new-item', item, True)
 	
 
 class Clipboard(object):
