@@ -22,8 +22,8 @@ class History(gobject.GObject):
 	def get_history(self):
 		return self.history
 	
-	def on_new_item(self, clipboards, item):
-		self.add(item)
+	def on_new_item(self, clipboards, item, is_from_selection):
+		self.add(item, is_from_selection)
 		get_glipper_plugins_manager().call('on_new_item', item)
 		
 	def clear(self):
@@ -48,15 +48,25 @@ class History(gobject.GObject):
 			self.history[index] = item 
 		self.emit('changed', self.history)
 	
-	def add(self, item):
+	def add(self, item, is_from_selection=False):
 		if item is not None:
 			item = unicode(item)
 			if item in self.history:
 				self.history.remove(item)
 			
-			self.history.insert(0, item)
+			last_item = self.history[0] if self.history else None
+			if is_from_selection and last_item is not None and \
+					(item.startswith(last_item) or item.endswith(last_item)):
+				self.history[0] = item
+			else:
+				self.history.insert(0, item)
+			
 			if len(self.history) > self.max_elements:
 				self.history = self.history[0:self.max_elements]
+			
+			ctrl_c_item = get_glipper_clipboards().get_default_clipboard_text()
+			if ctrl_c_item not in self.history:
+				self.history[-1] = ctrl_c_item
 		
 		# if item is None, emit changed anyway because 
 		# the current (bold) clipboard item has changed.
@@ -68,17 +78,22 @@ class History(gobject.GObject):
 	def load(self):
 		try:
 			file = open(glipper.HISTORY_FILE, "r")
-		except IOError:
-			self.emit('changed', self.history)
-			return # Cannot read history file
 		
-		length = file.readline()
-		while length:
-			self.history.append(unicode(file.read(int(length)), 'UTF-8'))
-			file.read(1) # This is for \n
 			length = file.readline()
+			while length:
+				try:
+					bytes_to_read = int(length)
+				except ValueError:
+					break
+				
+				self.history.append(unicode(file.read(bytes_to_read), 'UTF-8'))
+				file.read(1) # This is for \n
+				length = file.readline()
+		
+			file.close()
+		except IOError:
+			pass
 		
-		file.close()
 		self.emit('changed', self.history)
 		
 	def save(self):
